@@ -1,17 +1,19 @@
+"""listen to UDP packets from Rotorcraft-Pilot Coupling Task simulator"""
 from argparse import _SubParsersAction, ArgumentDefaultsHelpFormatter, ArgumentParser, Namespace
 from multiprocessing import Queue
 import socket
 from struct import unpack_from
 from typing import Tuple
 
-from ..mytypes import AircraftState, Buttons, Controls, RunFn
+from ..aircraft import *
+from ..mytypes import RunFn
 
 
 def setup(subparsers: _SubParsersAction) -> Tuple[str, RunFn]:
     NAME = 'rpctask'
     parser: ArgumentParser = subparsers.add_parser(
         NAME,
-        help='listen to UDP packets from Rotorcraft-Pilot Coupling Task simulator',
+        help=__doc__,
         formatter_class=ArgumentDefaultsHelpFormatter)
     parser.add_argument('-i', '--ip',
                         help='listen UDP adress', default='0.0.0.0')
@@ -29,7 +31,8 @@ def run(q: Queue, args: Namespace):
         # Timeout is required to handle leaving with Ctrl+C
         sock.settimeout(1.0)
         sock.bind((args.ip, args.port))
-        print(f'Listening for UDP packets on {args.ip}:{args.port}')
+        if args.verbosity >= 0:
+            print(f'Listening for UDP packets on {args.ip}:{args.port}')
 
         while True:
             try:
@@ -44,16 +47,19 @@ def run(q: Queue, args: Namespace):
                      up_bdr_coll, low_bdr_coll) = unpack_from('>' + 'd' * 6, data, 8 * 8)
 
                 state = AircraftState()
+                state.ctrl = Controls()
                 state.ctrl.stick_right = (roll_ctrl * 2.0) - 1.0
                 state.ctrl.stick_pull = (pitch_ctrl * -2.0) + 1.0
                 state.ctrl.collective_up = pwr_ctrl
                 state.trgt.stick_right = (roll_target * 2.0) - 1.0
                 state.trgt.stick_pull = (pitch_target * -2.0) + 1.0
                 state.trgt.collective_up = pwr_target
+                state.btn = Buttons()
                 if cyc_ftr > 0.5:
-                    state.btn |= Buttons.CYC_FTR
+                    state.btn.cyc_ftr = True
                 if coll_ftr > 0.5:
-                    state.btn |= Buttons.COLL_FTR
+                    state.btn.coll_ftr = True
+                state.brdr = Borders()
                 state.brdr.high.stick_right = (right_bdr_cyc * 2.0) - 1.0
                 state.brdr.low.stick_right = (left_bdr_cyc * 2.0) - 1.0
                 state.brdr.high.stick_pull = (low_bdr_cyc * -2.0) + 1.0
@@ -61,9 +67,9 @@ def run(q: Queue, args: Namespace):
                 state.brdr.high.collective_up = up_bdr_coll
                 state.brdr.low.collective_up = low_bdr_coll
 
-                if state.btn & Buttons.COLL_FTR:
+                if state.btn.coll_ftr:
                     last_trim.collective_up = state.ctrl.collective_up
-                if state.btn & Buttons.CYC_FTR:
+                if state.btn.cyc_ftr:
                     last_trim.stick_right = state.ctrl.stick_right
                     last_trim.stick_pull = state.ctrl.stick_pull
                 state.trim = last_trim
